@@ -1,6 +1,6 @@
 //
 // test_pekwm_panel.cc for pekwm
-// Copyright (C) 2021 Claes Nästén <pekdon@gmail.com>
+// Copyright (C) 2021-2025 Claes Nästén <pekdon@gmail.com>
 //
 // This program is licensed under the GNU GPL.
 // See the LICENSE file for more information.
@@ -8,7 +8,10 @@
 
 #include "test.hh"
 
-#include "pekwm.hh"
+#include "test_ExternalCommandData.hh"
+#include "test_TextFormatter.hh"
+
+#include "wm/pekwm.hh"
 #include "Debug.hh"
 #include "X11.hh"
 
@@ -19,6 +22,9 @@ main_tests(int argc, char *argv[])
 	Debug::setLogFile("/dev/null");
 	X11::addHead(Head(0, 0, 800, 600));
 
+	TestExternalCommandData externalCommandData;
+	TestTextFormatter textFormatter;
+
 	return TestSuite::main(argc, argv);
 }
 
